﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using SerrateTFC.Domain.Entities;
using SerrateTFC.Domain.Repositories;
using SerrateTFC.Localization.Exceptions;

namespace SerrateTFC.Domain.DomainServices
{
    public class UserDomainService : IUserDomainService
    {
        private readonly IUserRepository _userRepository;
        private const string AdminUsername = "admin";
        private const string AdminPassword = "admin";

        public UserDomainService(IUserRepository userRepository)
        {
            this._userRepository = userRepository;
        }

        public void SaveUser(User entity)
        {
            if (ExistsUsername(entity))
            {
                throw new Exception(Exceptions.UsernameAlreadyExists);
            }

            this._userRepository.SaveUser(entity);
        }

        public void DeleteUser(User entity)
        {
            this._userRepository.Delete(entity);
        }

        public User GetById(Guid id)
        {
            return this._userRepository.GetById(id);
        }

        public IEnumerable<User> GetAll()
        {
            return this._userRepository.GetAll();
        }

        private bool ExistsUsername(User entity)
        {
            if (string.Equals(AdminUsername, entity.UserName, StringComparison.InvariantCultureIgnoreCase))
                return true;

            return this._userRepository.Find(x => 
                string.Equals(x.UserName, entity.UserName, StringComparison.InvariantCultureIgnoreCase) &&
                x.Id != entity.Id
                ).Any();
        }

        public bool ValidateUser(string userName, string password)
        {
            if (string.Equals(AdminUsername, userName, StringComparison.InvariantCultureIgnoreCase)
                && string.Equals(AdminPassword, password, StringComparison.InvariantCultureIgnoreCase))
                return true;

            return this._userRepository.ValidateUser(userName, password);
        }

        public User GetUserByUsername(string userName)
        {
            if (string.Equals(AdminUsername, userName, StringComparison.InvariantCultureIgnoreCase))
                return new Administrator() { UserName = userName };

            return this._userRepository.Find(x => string.Equals(x.UserName, userName, StringComparison.InvariantCultureIgnoreCase)).SingleOrDefault();
        }
    }
}
