﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using SerrateTFC.Domain.Entities;
using SerrateTFC.Domain.Repositories;
using Microsoft.Practices.ServiceLocation;
using System.Data.Entity.Infrastructure;
using SerrateTFC.Localization.Exceptions;

namespace SerrateTFC.Infrastructure.Data.Repositories
{
    public class UserRepository :
        Repository<User>,
        IUserRepository
    {
        public UserRepository(IMainUnitOfWork unitOfWork)
            : base(unitOfWork)
        { }

        public void SaveUser(User entity)
        {
            this.SaveByEntityType(entity);
        }

        public bool ValidateUser(string userName, string password)
        {
            return this._dbSet.ToList().Any(x => string.Equals(x.UserName, userName, StringComparison.InvariantCultureIgnoreCase)
                && x.Password == password);
        }

        public override void Delete(User entity)
        {
            var projectRepository = ServiceLocator.Current.GetInstance<IProjectRepository>();

            var isUsed = projectRepository.Find(p => p.ProjectManagerId == entity.Id).Any();

            if (isUsed)
                throw new DbUpdateException(Exceptions.DbReferenceException);

            var taskRepository = ServiceLocator.Current.GetInstance<ITaskRepository>();
            isUsed = taskRepository.Find(t => t.AssignedId == entity.Id).Any();

            if (isUsed)
                throw new DbUpdateException(Exceptions.DbReferenceException);

            base.Delete(entity);
        }
    }
}
