﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.SessionState;
using Microsoft.Practices.Unity;
using Microsoft.Practices.ServiceLocation;
using SerrateTFC.Infrastructure.Data;
using SerrateTFC.Domain.Data;
using SerrateTFC.Domain.DomainServices;
using SerrateTFC.Domain.Repositories;
using SerrateTFC.Infrastructure.Data.Repositories;
using SerrateTFC.RestService.Unity;

namespace SerrateTFC.RestService
{
    public class Global : HttpApplication
    {
        private UnityContainer _container;

        protected void Application_Start(object sender, EventArgs e)
        {
            this._container = new UnityContainer();

            RegisterApplicationTypes();

            UnityServiceLocator locator = new UnityServiceLocator(_container);
            ServiceLocator.SetLocatorProvider(() => locator);
        }

        private void RegisterApplicationTypes()
        {
            this._container.RegisterType<MainUnitOfWork>(new WcfInstanceLifetimeManager<MainUnitOfWork>());
            this._container.RegisterType<IMainUnitOfWork, MainUnitOfWork>();
            this._container.RegisterType<IUnitOfWork, MainUnitOfWork>();


            this._container.RegisterType<ICustomerDomainService, CustomerDomainService>();
            this._container.RegisterType<ICustomerRepository, CustomerRepository>();
            this._container.RegisterType<IUserDomainService, UserDomainService>();
            this._container.RegisterType<IUserRepository, UserRepository>();
            this._container.RegisterType<IProjectRepository, ProjectRepository>();
            this._container.RegisterType<IProjectDomainService, ProjectDomainService>();
            this._container.RegisterType<ITaskRepository, TaskRepository>();
            this._container.RegisterType<ITaskDomainService, TaskDomainService>();
        }
    }
}