﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Microsoft.Practices.Unity;

namespace SerrateTFC.RestService.Unity
{
    /// <summary>
    /// El LifetimeManager per defecte de Unity ens retorna una instància nova a cada crida.
    /// Per a implementar UnitOfWork això no es interessa ja que hi estem desant tota la 
    /// informació dels canvis a persistir. 
    /// El codi per al Lifetime Manager de WCF s'ha extret del següent recurs:
    /// http://blog.lowendahl.net/?p=243
    /// ja que en WCF el HttpContext.Current sempre és NULL
    /// </summary>
    /// <typeparam name="T">Utilitzarem el tipus com la clau del diccionari</typeparam>
    public class WcfInstanceLifetimeManager<T> : LifetimeManager
    {
        private readonly Guid key;

        public WcfInstanceLifetimeManager()
        {
            key = Guid.NewGuid();
        }

        public override object GetValue()
        {
            return WcfServiceInstanceExtension.Current.Items.Find(key);
        }

        public override void SetValue(object newValue)
        {
            WcfServiceInstanceExtension.Current.Items.Set(key, newValue);
        }

        public override void RemoveValue()
        {
            WcfServiceInstanceExtension.Current.Items.Remove(key);
        }
    }
}