﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ServiceModel;

namespace SerrateTFC.RestService.Unity
{
    /// El codi per al Lifetime Manager de WCF s'ha extret del següent recurs:
    /// http://blog.lowendahl.net/?p=243
    /// ja que en WCF el HttpContext.Current sempre és NULL
    public class WcfServiceInstanceExtension : IExtension<InstanceContext>
    {
        public static WcfServiceInstanceExtension Current
        {
            get
            {
                if (OperationContext.Current == null)
                    return null;

                var instanceContext = OperationContext.Current.InstanceContext;

                return GetExtensionFrom(instanceContext);
            }
        }

        public static WcfServiceInstanceExtension GetExtensionFrom(InstanceContext instanceContext)
        {
            lock (instanceContext)
            {
                var extension = instanceContext.Extensions.Find<WcfServiceInstanceExtension>();

                if (extension == null)
                {
                    extension = new WcfServiceInstanceExtension();
                    extension.Items.Hook(instanceContext);
                    instanceContext.Extensions.Add(extension);
                }

                return extension;
            }
        }

        public InstanceItems Items = new InstanceItems();

        public void Attach(InstanceContext owner)
        { }

        public void Detach(InstanceContext owner)
        { }

    }
}