﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SerrateTFC.Domain.Data;
using SerrateTFC.Domain.DomainServices;
using AutoMapper;
using SerrateTFC.Domain.Entities;
using SerrateTFC.Web.Models;
using SerrateTFC.Domain.ValueObjects;
using SerrateTFC.Localization.Exceptions;
using SerrateTFC.Web.Extensions;
using SerrateTFC.Domain.Enums;

namespace SerrateTFC.Web.Controllers
{
    [UserTypeAuthorize(Roles.Administrator)]
    public class CustomerController : BaseController
    {
        private readonly IUnitOfWork _unitOfWork;
        private readonly ICustomerDomainService _customerDomainService;

        public CustomerController(
            IUnitOfWork unitOfWork, 
            ICustomerDomainService customerDomainService)
        {
            this._unitOfWork = unitOfWork;
            this._customerDomainService = customerDomainService;

            Mapper.CreateMap<Customer, CustomerView>();
            Mapper.CreateMap<Customer, CustomerDetails>();
            Mapper.CreateMap<CustomerDetails, Customer>()
                .ForMember(dest => dest.Address, opt => 
                    opt.MapFrom(src => new Address(src.AddressPublicAddress, src.AddressCity, src.AddressPostalCode, src.AddressCountry)));
        }

        public ActionResult Index()
        {
            var list = this._customerDomainService.GetAll();

            var listView = Mapper.Map<IEnumerable<Customer>, IEnumerable<CustomerView>>(list);

            return View(listView);
        }

        public ActionResult Details(Guid? id)
        {
            var details = new CustomerDetails();

            if (id.HasValue)
            {
                var customer = this._customerDomainService.GetById(id.Value);
                details = Mapper.Map<Customer, CustomerDetails>(customer);
            }
            else
            {
                details.Id = Guid.NewGuid();
            }

            return View(details);
        }

        [HttpPost]
        public ActionResult Details(CustomerDetails details)
        {
            if (!ModelState.IsValid)
            {
                return View(details);
            }

            var customer = Mapper.Map<CustomerDetails, Customer>(details);
            this._customerDomainService.SaveCustomer(customer);

            this._unitOfWork.SaveChanges();

            return RedirectToAction("Index");
        }

        [HttpPost]
        public ActionResult Delete(Guid id)
        {
            var customer = this._customerDomainService.GetById(id);
            if (customer == null)
                throw new ArgumentException(Exceptions.EntityNotFound);

            this._customerDomainService.DeleteCustomer(customer);
            this._unitOfWork.SaveChanges();

            return RedirectToAction("Index");
        }
    }
}
