﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SerrateTFC.Domain.DomainServices;
using SerrateTFC.Domain.Data;
using System.ServiceModel.Syndication;
using SerrateTFC.Web.Extensions;
using SerrateTFC.Localization.Exceptions;

namespace SerrateTFC.Web.Controllers
{
    public class FeedController : Controller
    {
        private readonly ITaskDomainService _taskDomainService;
        private readonly IUnitOfWork _unitOfWork;

        public FeedController(
            IUnitOfWork unitOfWork,
            ITaskDomainService taskDomainService)
        {
            this._unitOfWork = unitOfWork;
            this._taskDomainService = taskDomainService;
        }

        public ActionResult Tasks(Guid id)
        {
            var tasks = this._taskDomainService.GetTasksByProject(id);

            if (tasks.Count() < 1)
                throw new Exception(Exceptions.FeedProjectWithoutTasks);

            var feedItems = tasks.Select(t => new SyndicationItem(t.Name, t.Description, new Uri(AbsoluteAction("Task", "Details", new { id = t.Id }))));

            var project = tasks.FirstOrDefault().Project;

            if (!project.IsRssEnabled)
                throw new Exception(Exceptions.FeedProjectEnableRSS);

            var feed = new SyndicationFeed(project.Name, project.Description, new Uri(AbsoluteAction("Project", "Details", new { id = project.Id })), feedItems);

            return new FeedResult(new Rss20FeedFormatter(feed));
        }

        private string AbsoluteAction(string action, string controller, object routeValue)
        {
            Uri requestUrl = HttpContext.Request.Url;

            string absoluteAction = string.Format("{0}://{1}{2}", 
                requestUrl.Scheme, 
                requestUrl.Authority, 
                Url.Action(action, controller, routeValue));

            return absoluteAction;
        }

    }
}
