﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SerrateTFC.Domain.Enums;
using SerrateTFC.Domain.Entities;
using SerrateTFC.Domain.DomainServices;
using Microsoft.Practices.ServiceLocation;

namespace SerrateTFC.Web.Extensions
{
    public class UserTypeAuthorizeAttribute : FilterAttribute, IAuthorizationFilter
    {
        private readonly Roles[] _roles;

        public UserTypeAuthorizeAttribute(params Roles[] roles)
        {
            _roles = roles;
        }

        public void OnAuthorization(AuthorizationContext filterContext)
        {
            IUserDomainService service = ServiceLocator.Current.GetInstance<IUserDomainService>();
            var userName = HttpContext.Current.User.Identity.Name;
            User currentUser = service.GetUserByUsername(userName);

            bool isInRole = false;
            foreach (var item in _roles)
            {
                if (Compare(item, currentUser))
                {
                    isInRole = true;
                }
            }

            if (!isInRole)
            {
                throw new UnauthorizedAccessException();
            }
        }

        private bool Compare(Roles role, User user)
        {
            if (role == Roles.Administrator)
                return (user is Administrator);
            else if (role == Roles.ProjectManager)
                return (user is ProjectManager);
            else if (role == Roles.Resource)
                return (user is Resource);
            else
                return false;
        }
    }
}