﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Microsoft.Practices.Unity;

namespace SerrateTFC.Web.Unity
{
    /// <summary>
    /// El LifetimeManager per defecte de Unity ens retorna una instància nova a cada crida.
    /// Per a implementar UnitOfWork això no es interessa ja que hi estem desant tota la 
    /// informació dels canvis a persistir. 
    /// Per això aquest LifetimeManager personalitzat ens guarda la instància en el 
    /// context Http actual per a que sigui disponible durant tot el fil d’execució.
    /// </summary>
    /// <typeparam name="T">Utilitzarem el tipus com la clau del diccionari</typeparam>
    public class HttpContextLifetimeManager<T> : LifetimeManager, IDisposable
    {
        public override object GetValue()
        {
            return HttpContext.Current.Items[typeof(T).AssemblyQualifiedName];
        }

        public override void RemoveValue()
        {
            HttpContext.Current.Items.Remove(typeof(T).AssemblyQualifiedName);
        }

        public override void SetValue(object newValue)
        {
            HttpContext.Current.Items[typeof(T).AssemblyQualifiedName] = newValue;
        }

        public void Dispose()
        {
            RemoveValue();
        }
    }
}