﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.Generic;
using RestSharp;
using SerrateTFC.WindowsPhone.Dto;
using System.Collections.ObjectModel;

namespace SerrateTFC.WindowsPhone.ViewModels
{
    public class TaskDetailsViewModel : ViewModelBase
    {
        private Guid _id;
        private string _name;
        private string _description;
        private int _priority;
        private decimal _progress;
        private Guid _assignedId;
        private Guid _projectId;
        private DateTime _startDate;
        private DateTime _endDate;

        public Guid Id
        {
            get { return _id; }
            set 
            { 
                _id = value;
                NotifyPropertyChanged("Id");
            }
        }

        public string Name
        {
            get { return _name; }
            set
            {
                _name = value;
                NotifyPropertyChanged("Name");
            }
        }

        public string Description
        {
            get { return _description; }
            set
            {
                _description = value;
                NotifyPropertyChanged("Description");
            }
        }

        public int Priority
        {
            get { return _priority; }
            set
            {
                _priority = value;
                NotifyPropertyChanged("Priority");
            }
        }

        public decimal Progress
        {
            get { return _progress; }
            set
            {
                _progress = value;
                NotifyPropertyChanged("Progress");
            }
        }

        public Guid ProjectId
        {
            get { return _projectId; }
            set
            {
                _projectId = value;
                NotifyPropertyChanged("ProjectId");
            }
        }

        public Guid AssignedId
        {
            get { return _assignedId; }
            set
            {
                _assignedId = value;
                NotifyPropertyChanged("AssignedId");
            }
        }

        public DateTime StartDate
        {
            get { return _startDate; }
            set
            {
                _startDate = value;
                NotifyPropertyChanged("StartDate");
            }
        }

        public DateTime EndDate
        {
            get { return _endDate; }
            set
            {
                _endDate = value;
                NotifyPropertyChanged("EndDate");
            }
        }

        public ObservableCollection<KeyValue> Resources { get; private set; }

        public ObservableCollection<KeyValue> Projects { get; private set; }

        public ObservableCollection<string> Priorities { get; private set; }

        public void BindPriorities(Action action)
        {
            Priorities = new ObservableCollection<string>();
            Priorities.Add("Mitjà");
            Priorities.Add("Baix");
            Priorities.Add("Alt");

            action();
        }

        public void BindProjects(Action action)
        {
            var client = new RestClient(Globals.UrlService);
            var request = new RestRequest("Projects", Method.GET);

            client.ExecuteAsync<List<KeyValue>>(request, (response) =>
            {
                Projects = new ObservableCollection<KeyValue>();
                foreach (var item in response.Data)
                    Projects.Add(item);

                action();
            });            
        }

        public void BindResources(Action action)
        {
            var client = new RestClient(Globals.UrlService);
            var request = new RestRequest("Resources", Method.GET);

            client.ExecuteAsync<ObservableCollection<KeyValue>>(request, (response) =>
            {
                Resources = new ObservableCollection<KeyValue>();
                foreach (var item in response.Data)
                    Resources.Add(item);

                action();
            });
        }

        public TaskDetailsViewModel(Guid? id, Action action)
        {

            if (id.HasValue)
            {
                var client = new RestClient(Globals.UrlService);
                var request = new RestRequest("Task/{id}", Method.GET);
                request.AddUrlSegment("id", id.Value.ToString());

                client.ExecuteAsync<TaskDetailsResponse>(request, (response) =>
                {
                    Id = response.Data.Id;
                    Name = response.Data.Name;
                    Description = response.Data.Description;
                    Priority = response.Data.Priority;
                    Progress = response.Data.Progress;
                    ProjectId = response.Data.ProjectId;
                    AssignedId = response.Data.AssignedId;
                    StartDate = DateTime.Parse(response.Data.StartDate);
                    EndDate = DateTime.Parse(response.Data.EndDate);

                    action();

                });
            }
            else
            {
                Id = Guid.NewGuid();
                StartDate = DateTime.Now;
                EndDate = DateTime.Now.AddDays(10);
            }
        }

        public void Validate()
        {
            if (string.IsNullOrEmpty(Name))
                throw new Exception("El camp nom és obligatori");
        }

        public void Save(Action<bool> action)
        {
            var client = new RestClient(Globals.UrlService);
            var request = new RestRequest("SaveTask", Method.POST);
            var taskDetails = new TaskDetailsRequest()
            {
                Id = Id,
                Name = Name,
                Description = Description,
                AssignedId = AssignedId,
                ProjectId = ProjectId,
                Progress = Progress,
                StartDate = StartDate,
                EndDate = EndDate,
                Priority = Priority,
            };
            request.RequestFormat = DataFormat.Json;
            request.AddBody(taskDetails);

            client.ExecuteAsync(request, (response) =>
            {          
                action(response.ResponseStatus == ResponseStatus.Completed);
            });
        }
    }
}
