﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using SerrateTFC.WindowsPhone.ViewModels;
using System.Windows.Navigation;
using SerrateTFC.WindowsPhone.Dto;
using System.Collections.ObjectModel;

namespace SerrateTFC.WindowsPhone.Views
{
    public partial class TaskDetailsView : PhoneApplicationPage
    {
        private TaskDetailsViewModel _viewModel;

        public TaskDetailsView()
        {
            InitializeComponent();
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            if (_viewModel != null)
                return;

            var selectedItem = NavigationContext.QueryString.ContainsKey("selectedItem") ? NavigationContext.QueryString["selectedItem"] : string.Empty;
            Guid? id = null;

            if (!string.IsNullOrEmpty(selectedItem))
                id = new Guid(selectedItem);

            this.performanceProgressBar.IsIndeterminate = true;

            Action function = (() =>
                {
                    _viewModel.BindResources(() =>
                    {
                        var index = _viewModel.AssignedId;
                        this.listResources.ItemsSource = _viewModel.Resources;
                        var item = _viewModel.Resources.Where(x => x.Id == index).SingleOrDefault();
                        if (item != null)
                            this.listResources.SelectedItem = item;

                        this.performanceProgressBar.IsIndeterminate = false;
                    });

                    _viewModel.BindProjects(() =>
                    {
                        var index = _viewModel.ProjectId;
                        this.listProjects.ItemsSource = _viewModel.Projects;
                        var item = _viewModel.Projects.Where(x => x.Id == index).SingleOrDefault();
                        if (item != null)
                            this.listProjects.SelectedItem = item;

                        this.performanceProgressBar.IsIndeterminate = false;
                    });

                    _viewModel.BindPriorities(() =>
                    {
                        var index = _viewModel.Priority;
                        this.listPriorities.ItemsSource = _viewModel.Priorities;
                        this.listPriorities.SelectedIndex = index;
                    });
                });

            _viewModel = new TaskDetailsViewModel(id, function);
            if (id == null)
                function();

            DataContext = _viewModel;

        }

        private void appbar_cancelTask_Click(object sender, EventArgs e)
        {
            NavigationService.GoBack();
        }

        private void appbar_saveTask_Click(object sender, EventArgs e)
        {
            try
            {
                _viewModel.Validate();

                this.performanceProgressBar.IsIndeterminate = true;
                _viewModel.Save((bool IsOk) =>
                {
                    this.performanceProgressBar.IsIndeterminate = false;
                    if (!IsOk)
                        MessageBox.Show("Error al guardar les dades");
                    else
                        MessageBox.Show("Dades guardades correctament");
                });
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        private void listPriorities_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            var index = listPriorities.SelectedIndex;
            _viewModel.Priority = index;
        }

        private void listResources_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            var keyValue = listResources.SelectedItem as KeyValue;
            _viewModel.AssignedId = keyValue.Id;
        }

        private void listProjects_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            var keyValue = listProjects.SelectedItem as KeyValue;
            _viewModel.ProjectId = keyValue.Id;
        }
    }
}